@@ -1,31 +1,34 @@
 use crate::math::Vec3;
-use crate::shapes::Sphere;
+use crate::rendering::Material;
 
 /// The intersection of a ray with an object.
 #[derive(Copy, Clone, Debug)]
-pub struct Hit {
-    object: Sphere,
+pub struct Hit<'a> {
     position: Vec3,
     normal: Vec3,
     distance: f64,
+    material: &'a Box<dyn Material>,
+    uv: (f64, f64),
 }
 
-impl Hit {
+impl<'a> Hit<'a> {
     /// Create a new hit.
-    pub fn new(object: Sphere, position: Vec3, normal: Vec3, distance: f64) -> Self {
+    pub fn new(
+        position: Vec3,
+        normal: Vec3,
+        distance: f64,
+        material: &'a Box<dyn Material>,
+        uv: (f64, f64),
+    ) -> Self {
         Hit {
-            object,
             position,
             normal,
             distance,
+            material,
+            uv,
         }
     }
 
-    /// Return the object that is hit by the ray.
-    pub fn object(&self) -> Sphere {
-        self.object
-    }
-
     /// Return the position of the intersection point.
     pub fn position(&self) -> Vec3 {
         self.position
@@ -40,4 +43,13 @@ impl Hit {
     pub fn distance(&self) -> f64 {
         self.distance
     }
+
+    /// Return the object that is hit by the ray.
+    pub fn material(&self) -> &Box<dyn Material> {
+        &self.material
+    }
+
+    pub fn uv(&self) -> (f64, f64) {
+        self.uv
+    }
 }
