@@ -2,7 +2,7 @@
 
 pub use hit::Hit;
 pub use ray::Ray;
-pub use vec3::{cross_product, dot_product, Vec3};
+pub use vec3::Vec3;
 
 mod hit;
 mod ray;
