@@ -1,19 +1,22 @@
 use crate::math::Vec3;
 
 /// A ray (half-line).
-#[derive(Copy, Clone, Debug)]
+#[derive(Copy, Clone, Debug, PartialEq)]
 pub struct Ray {
     origin: Vec3,
     direction: Vec3,
+    last_ior: f64,
 }
 
 impl Ray {
     /// Create a new ray.
-    pub fn new(origin: Vec3, direction: Vec3) -> Self {
+    pub fn new(origin: Vec3, direction: Vec3, last_ior: f64) -> Self {
+        let direction = direction.normalize();
         Ray {
             // Shift the intersection point slightly outwards in order to avoid problems due to finite floating point precision.
             origin: origin + direction * 1e-9,
-            direction: direction.normalize(),
+            direction,
+            last_ior,
         }
     }
 
@@ -27,6 +30,11 @@ impl Ray {
         self.direction
     }
 
+    /// Return the index of refraction of the material the ray came from.
+    pub fn last_ior(&self) -> f64 {
+        self.last_ior
+    }
+
     /// Return the point on the ray at the given distance.
     pub fn get_point(&self, distance: f64) -> Vec3 {
         self.origin + self.direction * distance
@@ -42,11 +50,16 @@ mod tests {
     #[test]
     fn ray_get_point() {
         assert_approx_eq!(
-            Ray::new(Vec3::new(0.0, 0.0, 0.0), Vec3::new(1.0, 0.0, 0.0)).get_point(2.0),
+            Ray::new(Vec3::new(0.0, 0.0, 0.0), Vec3::new(1.0, 0.0, 0.0), 1.0).get_point(2.0),
             Vec3::new(2.0, 0.0, 0.0)
         );
         assert_approx_eq!(
-            Ray::new(Vec3::new(5.72, 2.5, 8.824), Vec3::new(8.7, 5.987, 0.12)).get_point(2.5),
+            Ray::new(
+                Vec3::new(5.72, 2.5, 8.824),
+                Vec3::new(8.7, 5.987, 0.12),
+                1.0
+            )
+            .get_point(2.5),
             Vec3::new(7.779336, 3.917155, 8.852405)
         );
     }
