@@ -1,7 +1,7 @@
 //! Data Types and functions related to rendering.
 
 pub use camera::Camera;
-pub use material::{BackgroundMaterial, Material};
+pub use material::{Diffuse, Emissive, Material, Metallic, Refractive};
 pub use render_engine::RenderEngine;
 pub use scene::Scene;
 
